@@ -73,6 +73,9 @@ class TimeLogMiddleware(MiddlewareMixin):
                 ps = pstats.Stats(request.pr, stream=s).sort_stats(sort_by)
                 ps.print_stats()
                 if exec_time > config.SL_CPROFILE_LOG_MIN_SECONDS:
+                    subject = '长时间请求 cProfile %fs' % exec_time
+                    content = '<pre>%s</pre>' % s.getvalue()
+                    utility.sendEmail(subject, settings.ADMINS, content)
                     self.logger.info("%s %s time:%f stat: %s" % (
                         request.path, request.META['QUERY_STRING'], exec_time, s.getvalue()
                     ))
